PubChemCompound

Struct PubChemCompound 

pub struct PubChemCompound {
    pub cid: u64,
    pub iupac_name: Option<String>,
    pub canonical_smiles: Option<String>,
    pub inchi: Option<String>,
    pub inchi_key: Option<String>,
    pub molecular_formula: Option<String>,
    pub molecular_weight: Option<f64>,
}
Compound data returned from a successful PubChem lookup.

Fields

cid: u64

PubChem Compound ID.

iupac_name: Option<String>

Preferred IUPAC name as assigned by PubChem.

canonical_smiles: Option<String>

Canonical SMILES string.

inchi: Option<String>

Standard InChI string.

inchi_key: Option<String>

27-character InChIKey.

molecular_formula: Option<String>

Hill-notation molecular formula.

molecular_weight: Option<f64>

Molecular weight in g/mol.

Implementations

Source

impl PubChemCompound

pub fn apply_to(&self, id: &mut SubstanceIdentifier)

Copy fields from this compound into id, filling only the missing fields.

The CID is always set. Other fields are only written if the identifier field is currently None.